@@ -1,6 +1,7 @@
-      SUBROUTINE VORONOI(NCC,LCC,N,X,Y,LIST,LPTR,LEND,NT,LCCC,LCT,IER)
+      SUBROUTINE VORONOI(NCC,LCC,N,X,Y,LIST,LPTR,LEND,NT,LCCC,LCT,
+     .                   LTRI,IER)
       INTEGER NCC, LCC(*), N, LIST(*), LPTR(*), LEND(N),
-     .        NT, LCT(NCC), IER
+     .        NT, LCT(NCC), IER, LTRI(9,*) 
       DOUBLE PRECISION X(*), Y(*), LCCC(9,*)
 C
 C     DETERMINE A VORONOI MOSAIC. TO BE USED WITH THE FUNCTIONS FROM TRIPACK.
@@ -30,7 +31,7 @@ C
 C     Modules required by VORONOI:  TRLIST, CIRCUM, QSORT, RMSHNB
 
 C     DETERMINE ALL CIRCUMCIRCLE CENTERS
-      INTEGER LTRI(9,2*N), NROW, IT, IN, IP(3), NTRI, IT1, IT2
+      INTEGER NROW, IT, IN, IP(3), NTRI, IT1, IT2
       DOUBLE PRECISION X1, X2, X3, Y1, Y2, Y3, XC, YC, CA, SA, AR, 
      .     XP(3), YP(3)
       LOGICAL RATIO
